// src/index.ts
import {getHighlighter} from "shiki";
import deasync from "deasync";
import Debug from "debug";
var debug = Debug("markdown-it-shiki");
var MarkdownItShiki = (markdownit, options = {}) => {
  let _highlighter = void 0;
  const themes = [];
  let darkModeThemes;
  if (!options.theme) {
    themes.push("nord");
  } else if (typeof options.theme === "string") {
    themes.push(options.theme);
  } else {
    darkModeThemes = options.theme;
    themes.push(options.theme.dark);
    themes.push(options.theme.light);
  }
  const {
    timeout = 1e4,
    langs
  } = options;
  getHighlighter({themes, langs}).then((h) => {
    _highlighter = h;
  });
  markdownit.options.highlight = (code, lang) => {
    if (!_highlighter) {
      debug("awaiting getHighlighter()");
      let count = timeout / 200;
      while (!_highlighter) {
        deasync.sleep(200);
        count -= 1;
        if (count <= 0)
          throw new Error("Shiki.getHighlighter() never gets resolved");
      }
      debug("getHighlighter() resolved");
    }
    if (darkModeThemes) {
      const dark = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.dark);
      const light = _highlighter.codeToHtml(code, lang || "text", darkModeThemes.light);
      return dark.replace('<pre class="shiki"', '<pre class="shiki shiki-dark"') + light.replace('<pre class="shiki"', '<pre class="shiki shiki-light"');
    } else {
      return _highlighter.codeToHtml(code, lang || "text");
    }
  };
};
var src_default = MarkdownItShiki;
export {
  src_default as default
};
